(configure-mu)(configure-mu options)configure mu-server with bunch of options. If no options are passed in mu will start an http server on a free port. This function does not start mu-server. See the start-mu function to start mu-server.
options need to be passed in as a map as follows
:port - http port to start up on :https-port - https port to start up on
configure mu-server with bunch of options. If no options are passed in mu will start an http server on a free port. This function does not start mu-server. See the start-mu function to start mu-server. options need to be passed in as a map as follows :port - http port to start up on :https-port - https port to start up on
(extract-request request params)return more of a clojure style request object back so that the handler can be more clojure like
return more of a clojure style request object back so that the handler can be more clojure like
(run-mu)(run-mu options)helper function to help with some testing
helper function to help with some testing
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |